@@ -1,4 +1,4 @@
- # Copyright (C) 2010 Oscar Perpiñán Lamigueiro
+ # Copyright (C) 2011, 2010 Oscar Perpiñán Lamigueiro
  #
  # This program is free software; you can redistribute it and/or
  # modify it under the terms of the GNU General Public License
@@ -112,7 +112,7 @@ setClass(
          Class='Shade',
          representation=representation(
            FS='numeric',
-           GCR='numeric',
+           GRR='numeric',
            Yf='numeric',
            FS.loess='loess',
            Yf.loess='loess',
