@@ -1,4 +1,4 @@
- # Copyright (C) 2009, 2010 Oscar Perpiñán Lamigueiro
+ # Copyright (C) 2011, 2010, 2009 Oscar Perpiñán Lamigueiro
  #
  # This program is free software; you can redistribute it and/or
  # modify it under the terms of the GNU General Public License
@@ -15,15 +15,26 @@
  # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  #/
 fSolD<-function(lat, BTd){
+  if (abs(lat)>90){
+    lat=sign(lat)*90
+    warning(paste('Latitude outside acceptable values. Set to', lat))
+  }
+  
   lat=d2r(lat)
+
   if (missing(BTd)) BTd=fBTd(mode='prom')
 
-  dn<-as.numeric(format(BTd,'%j')) #Día del año
-  decl=23.45*sin(2*pi*(dn+284)/365); #declinación
-  decl=d2r(decl);                    #Paso a radianes
-  ro=1.496E8;                        #distancia media Tierra-Sol (km)
-  eo=1+0.033*cos(2*pi*dn/365);       # factor de corrección excentrica
-  ws=-acos(-tan(decl)*tan(lat)); #Amanecer, definido como ángulo negativo (antes del mediodia)
+  dn <- doy(BTd)                     #día del año
+  decl=23.45*sin(2*pi*(dn+284)/365) #declinación
+  decl=d2r(decl)                    #Paso a radianes
+  ro=1.496E8                        #distancia media Tierra-Sol (km)
+  eo=1+0.033*cos(2*pi*dn/365)       # factor de corrección excentrica
+
+  ##Duración del día
+  cosWs=-tan(lat)*tan(decl)
+ws=suppressWarnings(-acos(cosWs)) #Amanecer, definido como ángulo negativo (antes del mediodia)
+polar <- which(is.nan(ws)) ##¿Día o noche polar?
+ws[polar] <- -pi*(cosWs[polar] < -1) + 0*(cosWs[polar] >1)
   
   ##Ecuación del tiempo, minutos
   ##según Alan M.Whitman "A simple expression for the equation of time"
@@ -33,10 +44,10 @@ fSolD<-function(lat, BTd){
   EoT.min=229.18*(-0.0334*sin(M)+0.04184*sin(2*M+3.5884))
   EoT=h2r(EoT.min/60)                   #radianes
 
-  Bo=1367;                              #constante solar
-  Bo0d=-24/pi*Bo*eo*(ws*sin(lat)*sin(decl)+cos(lat)*cos(decl)*sin(ws)); #el signo negativo se debe a la definición de ws
+  Bo=1367                              #constante solar
+  Bo0d=-24/pi*Bo*eo*(ws*sin(lat)*sin(decl)+cos(lat)*cos(decl)*sin(ws)) #el signo negativo se debe a la definición de ws
 
-  result<-zoo(data.frame(decl=decl,eo=eo,ws=ws,Bo0d=Bo0d, EoT=EoT), BTd)
+  result<-zoo(data.frame(decl=decl,eo=eo,ws=ws,Bo0d=Bo0d, EoT=EoT), truncDay(BTd))
   attr(result, 'lat')=r2d(lat)
   result
 }
